@@ -8,7 +8,6 @@ from cubicweb.schema import display_name
 from cubicweb.view import EntityView
 from cubicweb.selectors import is_instance
 from cubicweb.web.views.calendar import CalendarItemView, OneMonthCal
-from cubicweb.web.views.old_calendar import _CalendarView
 
 from cubes.calendar import NON_WORKING, WORKING, WORKING_AM, WORKING_PM
 from cubes.calendar.views import get_date_range_from_reqform
@@ -18,44 +17,6 @@ CALENDARS_PAGE = u"""<table class="bigCalendars">
 </table>
 """
 
-class ActivityMonthCalendarView(_CalendarView):
-    """this viewca renders a 3x1 calendars' table"""
-    __regid__ = 'calendaronemonth'
-    title = _('calendar (one month)')
-
-    def nav_header(self, curdate):
-        self._cw.add_js('cubicweb.ajax.js')
-        prevdate = previous_month(curdate)
-        nextdate = next_month(curdate)
-        rql = self._cw.url_quote(self.cw_rset.printable_rql())
-        prevlink = self._cw.ajax_replace_url('onemonthcal', rql=rql,
-                                             vid='calendaronemonth',
-                                             year=prevdate.year,
-                                             month=prevdate.month)
-        nextlink = self._cw.ajax_replace_url('onemonthcal', rql=rql,
-                                             vid='calendaronemonth',
-                                             year=nextdate.year,
-                                             month=nextdate.month)
-        self.w(u"""<table class="calendarPageHeader">
-<tr><td class="prev"><a href="%s">&lt;&lt;</a></td>
-<td class="next"><a href="%s">&gt;&gt;</a></td></tr>
-</table>""" % (xml_escape(prevlink), xml_escape(nextlink)))
-
-
-    def call(self, year=None, month=None):
-        _today = pydate.today()
-        year = int(self._cw.form.get('year', _today.year))
-        month = int(self._cw.form.get('month', _today.month))
-        center_date = pydate(year, month, 1)
-        begin, end = self.get_date_range(day=center_date, shift=0)
-        schedule = self._mk_schedule(begin, end)
-        calendars = self.build_calendars(schedule, begin, end)
-        self.w(u'<div id="onemonthcal">')
-        self.nav_header(center_date)
-        self.w(CALENDARS_PAGE % tuple(calendars))
-        self.w(u'</div>')
-
-
 class EuserCalendar(EntityView):
     __select__ = is_instance('Calendar',)
     __regid__ = 'user_calendar'
@@ -147,7 +108,8 @@ class TimeperiodCalendarItemView(EntityView):
     __regid__ = 'calendaritem'
     __select__ = is_instance('Timeperiod',)
     def cell_call(self, row, col):
-        entity = self.complete_entity(row, col)
+        entity = self.cw_rset.complete_entity(row, col)
         day_types = u' '.join(self._cw._(dt.type) for dt in entity.day_type)
-        calendar = entity.from_calendar
-        self.w(xml_escape(u'%s : %s (%s)' % (calendar.title, day_types, self._cw._(entity.state))))
+        state = entity.cw_adapt_to('IWorkflowable').printable_state
+        self.w(xml_escape(u'%s : %s (%s)' % (entity.from_calendar.title,
+                                             day_types, state)))
