@@ -1,11 +1,11 @@
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web.views import primary
 from cubicweb.uilib import toggle_link
 
 # calendar  ######################################################################
 
 class PrimaryCalendar(primary.PrimaryView):
-    __select__ = implements('Calendar')
+    __select__ = is_instance('Calendar')
 
     def render_entity_attributes(self, entity):
         entity.view('user_calendar', w=self.w)
